@@ -365,6 +365,10 @@ In case the service has been recently started please wait 5 minutes for it to be
                 print(
                     "You are not authorized to access this service. Please try to authenticate first."
                 )
+            elif "Under Maintenance" in result:
+                print(
+                    "The remote service is currently under maintenance. Please try again later."
+                )
             else:
                 print(
                     f"Job submission has failed with http status code: {status_code}. \nRemote server response: '{result}'"
